'use strict';

var solidJs = require('solid-js');

// src/index.ts
function resolveChildren(resolved, children, symbol) {
  if (typeof children === "function" && !children.length) {
    if (symbol in children)
      resolved.push(children);
    else
      resolveChildren(resolved, children(), symbol);
  }
  if (Array.isArray(children))
    for (let i = 0; i < children.length; i++)
      resolveChildren(resolved, children[i], symbol);
}
function createJSXParser(options) {
  const name = options?.name || true ? "jsx-parser" : "";
  const id = Symbol(name);
  function createToken(tokenCallback, component) {
    return (props) => Object.assign(
      component ? () => solidJs.untrack(() => component(props)) : () => {
        console.warn(`tokens can only be rendered inside a Parser with id '${name}'`);
        return "";
      },
      {
        [id]: true,
        ...tokenCallback(props)
      }
    );
  }
  function childrenTokens(fn) {
    const children = solidJs.createMemo(fn);
    return solidJs.createMemo(() => {
      const tokens = [];
      resolveChildren(tokens, children(), id);
      return tokens;
    });
  }
  function isToken(value) {
    return typeof value === "function" && !value.length && id in value;
  }
  return { createToken, childrenTokens, isToken, id };
}

exports.createJSXParser = createJSXParser;
